PRAGMA foreign_keys = on;

-- a user jid will never change, only a chat user will change
-- TODO: avatar, nick, etc.
create table user(
    jid jid primary key,
    -- can receive presence status from non-contacts
    cached_status text,
);

-- enum for subscription state
create table subscription(
    state text primary key,
);

insert into subscription ( state ) values ('none'), ('pending-out'), ('pending-in'), ('only-out'), ('only-in'), ('out-pending-in'), ('in-pending-out'), ('buddy');

-- a roster contains users, with client-set nickname
CREATE TABLE roster( 
    jid jid primary key,
    name TEXT,
    subscription text not null,
    foreign key(subscription) references subscription(state),
    foreign key(jid) references users(jid)
);

create table groups(
    group text primary key
);

create table groups_roster(
    group_id text,
    contact_id jid,
    foreign key(group_id) references group(id),
    foreign key(contact_id) references roster(id),
    primary key(group_id, contact_id)
);

-- chat includes reference to user jid chat is with
-- specifically for dms, groups should be different
-- can send chat message to user (creating a new chat if not already exists)
create table chats (
    id uuid primary key,
    user_id jid not null unique,
);

-- messages include reference to chat they are in, and who sent them.
create table messages (
    id uuid primary key,
    body text,
    chat_id uuid not null,
    -- TODO: from can be either a jid, a moved jid (for when a contact moves, save original sender jid/user but link to new user), or imported (from another service (save details), linked to new user)
    from jid not null,
    -- TODO: read bool not null,
    foreign key(chat_id) references chats(id),
    foreign key(from) references users(jid)
);
